@@ -909,6 +909,10 @@ class ExecContext(BaseContext):
         """
         self._pending_order_scope.remove_all(symbol)
 
+    def cancel_stop(self, stop_id: int) -> bool:
+        """Cancels a :class:`pybroker.portfolio.Stop` with ``stop_id``."""
+        return self._portfolio.remove_stop(stop_id)
+
     def cancel_stops(
         self,
         val: Union[str, Position, Entry],
