@@ -212,33 +212,60 @@ def log_profit_factor(changes: NDArray[np.float_]) -> np.floating:
 
 
 @njit
-def sharpe_ratio(changes: NDArray[np.float_]) -> np.floating:
+def sharpe_ratio(
+    changes: NDArray[np.float_], obs: Optional[int] = None
+) -> np.floating:
     """Computes the
     `Sharpe Ratio <https://en.wikipedia.org/wiki/Sharpe_ratio>`_.
 
     Args:
         changes: Array of differences between each bar and the previous bar.
+        obs: Number of observations used to annualize the Sharpe Ratio. For
+            example, a value of ``252`` would be used to annualize daily
+            returns.
     """
     if not len(changes):
         return np.float32(0)
     std = np.std(changes)
     if std == 0:
         return np.float32(0)
-    return np.mean(changes) / std
+    sr = np.mean(changes) / std
+    if obs is not None:
+        sr *= np.sqrt(obs)
+    return sr
 
 
 def conf_profit_factor(
     x: NDArray[np.float_], n: int, n_boot: int
 ) -> BootConfIntervals:
-    """Computes confidence intervals for :func:`.log_profit_factor`."""
-    return bca_boot_conf(x, n, n_boot, log_profit_factor)
+    """Computes confidence intervals for :func:`.profit_factor`."""
+    intervals = bca_boot_conf(x, n, n_boot, log_profit_factor)
+    return BootConfIntervals(
+        low_2p5=np.exp(intervals.low_2p5),
+        high_2p5=np.exp(intervals.high_2p5),
+        low_5=np.exp(intervals.low_5),
+        high_5=np.exp(intervals.high_5),
+        low_10=np.exp(intervals.low_10),
+        high_10=np.exp(intervals.high_10),
+    )
 
 
 def conf_sharpe_ratio(
-    x: NDArray[np.float_], n: int, n_boot: int
+    x: NDArray[np.float_], n: int, n_boot: int, obs: Optional[int] = None
 ) -> BootConfIntervals:
     """Computes confidence intervals for :func:`.sharpe_ratio`."""
-    return bca_boot_conf(x, n, n_boot, sharpe_ratio)
+    intervals = bca_boot_conf(x, n, n_boot, sharpe_ratio)
+    if obs is not None:
+        factor = np.sqrt(obs)
+        intervals = BootConfIntervals(
+            low_2p5=intervals.low_2p5 * factor,
+            high_2p5=intervals.high_2p5 * factor,
+            low_5=intervals.low_5 * factor,
+            high_5=intervals.high_5 * factor,
+            low_10=intervals.low_10 * factor,
+            high_10=intervals.high_10 * factor,
+        )
+    return intervals
 
 
 @njit
@@ -315,14 +342,14 @@ class DrawdownMetrics(NamedTuple):
     """Contains drawdown metrics.
 
     Attributes:
-        drawdown_confs: Upper bounds of confidence intervals for maximum
+        confs: Upper bounds of confidence intervals for maximum
             drawdown, measured in cash.
-        drawdown_pct_confs: Upper bounds of confidence intervals for maximum
+        pct_confs: Upper bounds of confidence intervals for maximum
             drawdown, measured in percentage.
     """
 
-    drawdown_confs: DrawdownConfs
-    drawdown_pct_confs: DrawdownConfs
+    confs: DrawdownConfs
+    pct_confs: DrawdownConfs
 
 
 @njit
@@ -597,10 +624,16 @@ class BootstrapResult(NamedTuple):
             intervals for :func:`.log_profit_factor` and :func:`.sharpe_ratio`.
         drawdown_conf: :class:`pandas.DataFrame` containing upper bounds of
             confidence intervals for maximum drawdown.
+        profit_factor: Contains profit factor confidence intervals.
+        sharpe: Contains Sharpe Ratio confidence intervals.
+        drawdown: Contains drawdown confidence intervals.
     """
 
     conf_intervals: pd.DataFrame
     drawdown_conf: pd.DataFrame
+    profit_factor: BootConfIntervals
+    sharpe: BootConfIntervals
+    drawdown: DrawdownMetrics
 
 
 @dataclass(frozen=True)
@@ -636,8 +669,10 @@ class EvalMetrics:
         avg_loss_pct: Average loss per trade, measured in percentage.
         avg_losing_trade_bars: Average number of bars per losing trade.
         largest_win: Largest profit of a trade, measured in cash.
+        largest_win_pct: Largest profit of a trade, measured in percentage
         largest_win_bars: Number of bars in the largest winning trade.
         largest_loss: Largest loss of a trade, measured in cash.
+        largest_loss_pct: Largest loss of a trade, measured in percentage.
         largest_loss_bars: Number of bars in the largest losing trade.
         max_wins: Maximum number of consecutive winning trades.
         max_losses: Maximum number of consecutive losing trades.
@@ -679,8 +714,10 @@ class EvalMetrics:
     avg_loss_pct: float = field(default=0)
     avg_losing_trade_bars: float = field(default=0)
     largest_win: float = field(default=0)
+    largest_win_pct: float = field(default=0)
     largest_win_bars: int = field(default=0)
     largest_loss: float = field(default=0)
+    largest_loss_pct: float = field(default=0)
     largest_loss_bars: int = field(default=0)
     max_wins: int = field(default=0)
     max_losses: int = field(default=0)
@@ -720,6 +757,17 @@ class EvalResult(NamedTuple):
     bootstrap: Optional[BootstrapResult]
 
 
+class _ConfsResult(NamedTuple):
+    df: pd.DataFrame
+    profit_factor: BootConfIntervals
+    sharpe: BootConfIntervals
+
+
+class _DrawdownResult(NamedTuple):
+    df: pd.DataFrame
+    metrics: DrawdownMetrics
+
+
 class EvaluateMixin:
     """Mixin for computing evaluation metrics."""
 
@@ -730,6 +778,7 @@ class EvaluateMixin:
         calc_bootstrap: bool,
         bootstrap_sample_size: int,
         bootstrap_samples: int,
+        sharpe_length: Optional[int],
     ) -> EvalResult:
         """Computes evaluation metrics.
 
@@ -740,6 +789,9 @@ class EvaluateMixin:
             calc_bootstrap: ``True`` to calculate randomized bootstrap metrics.
             bootstrap_sample_size: Size of each random bootstrap sample.
             bootstrap_samples: Number of random bootstrap samples to use.
+            sharpe_length: Number of observations used to annualize the Sharpe
+                Ratio. For example, a value of ``252`` would be used to
+                annualize daily returns.
 
         Returns:
             :class:`.EvalResult` containing evaluation metrics.
@@ -760,10 +812,16 @@ class EvaluateMixin:
         winning_bars = trades_df[trades_df["pnl"] > 0]["bars"].to_numpy()
         losing_bars = trades_df[trades_df["pnl"] < 0]["bars"].to_numpy()
         largest_win = trades_df[trades_df["pnl"] == trades_df["pnl"].max()]
+        largest_win_pct = (
+            0 if largest_win.empty else largest_win["return_pct"].values[0]
+        )
         largest_win_bars = (
             0 if largest_win.empty else largest_win["bars"].values[0]
         )
         largest_loss = trades_df[trades_df["pnl"] == trades_df["pnl"].min()]
+        largest_loss_pct = (
+            0 if largest_loss.empty else largest_loss["return_pct"].values[0]
+        )
         largest_loss_bars = (
             0 if largest_loss.empty else largest_loss["bars"].values[0]
         )
@@ -777,8 +835,11 @@ class EvaluateMixin:
             winning_bars=winning_bars,
             losing_bars=losing_bars,
             largest_win_num_bars=largest_win_bars,
+            largest_win_pct=largest_win_pct,
             largest_loss_num_bars=largest_loss_bars,
+            largest_loss_pct=largest_loss_pct,
             fees=fees,
+            sharpe_length=sharpe_length,
         )
         logger = StaticScope.instance().logger
         if not calc_bootstrap:
@@ -790,16 +851,25 @@ class EvaluateMixin:
         logger.calc_bootstrap_metrics_start(
             samples=bootstrap_samples, sample_size=bootstrap_sample_size
         )
-        conf_intervals = self._calc_conf_intervals(
-            bar_changes, bootstrap_sample_size, bootstrap_samples
+        confs_result = self._calc_conf_intervals(
+            bar_changes,
+            bootstrap_sample_size,
+            bootstrap_samples,
+            sharpe_length,
         )
-        dd_conf = self._calc_drawdown_conf(
+        dd_result = self._calc_drawdown_conf(
             bar_changes,
             bar_returns,
             bootstrap_sample_size,
             bootstrap_samples,
         )
-        bootstrap = BootstrapResult(conf_intervals, dd_conf)
+        bootstrap = BootstrapResult(
+            conf_intervals=confs_result.df,
+            drawdown_conf=dd_result.df,
+            profit_factor=confs_result.profit_factor,
+            sharpe=confs_result.sharpe,
+            drawdown=dd_result.metrics,
+        )
         logger.calc_bootstrap_metrics_completed()
         return EvalResult(metrics, bootstrap)
 
@@ -823,13 +893,16 @@ class EvaluateMixin:
         winning_bars: NDArray[np.int_],
         losing_bars: NDArray[np.int_],
         largest_win_num_bars: int,
+        largest_win_pct: float,
         largest_loss_num_bars: int,
+        largest_loss_pct: float,
         fees: NDArray[np.float_],
+        sharpe_length: Optional[int],
     ) -> EvalMetrics:
         total_fees = fees[-1] if len(fees) else 0
         max_dd = max_drawdown(bar_changes)
         max_dd_pct = max_drawdown_percent(bar_returns)
-        sharpe = sharpe_ratio(bar_changes)
+        sharpe = sharpe_ratio(bar_changes, sharpe_length)
         pf = profit_factor(bar_changes)
         r2 = r_squared(market_values)
         ui = ulcer_index(market_values)
@@ -887,8 +960,10 @@ class EvaluateMixin:
             max_drawdown=max_dd,
             max_drawdown_pct=max_dd_pct,
             largest_win=largest_win,
+            largest_win_pct=largest_win_pct,
             largest_win_bars=largest_win_num_bars,
             largest_loss=largest_loss,
+            largest_loss_pct=largest_loss_pct,
             largest_loss_bars=largest_loss_num_bars,
             max_wins=max_wins,
             max_losses=max_losses,
@@ -924,19 +999,21 @@ class EvaluateMixin:
         changes: NDArray[np.float_],
         sample_size: int,
         samples: int,
-    ) -> pd.DataFrame:
-        pf_conf = self._to_conf_intervals(
-            "Log Profit Factor",
-            conf_profit_factor(changes, sample_size, samples),
-        )
-        sharpe_conf = self._to_conf_intervals(
-            "Sharpe Ratio", conf_sharpe_ratio(changes, sample_size, samples)
+        sharpe_length: Optional[int],
+    ) -> _ConfsResult:
+        pf_intervals = conf_profit_factor(changes, sample_size, samples)
+        pf_conf = self._to_conf_intervals("Profit Factor", pf_intervals)
+        sr_intervals = conf_sharpe_ratio(
+            changes, sample_size, samples, sharpe_length
         )
+        sharpe_conf = self._to_conf_intervals("Sharpe Ratio", sr_intervals)
         df = pd.DataFrame.from_records(
             pf_conf + sharpe_conf, columns=ConfInterval._fields
         )
         df.set_index(["name", "conf"], inplace=True)
-        return df
+        return _ConfsResult(
+            df=df, profit_factor=pf_intervals, sharpe=sr_intervals
+        )
 
     def _to_conf_intervals(
         self, name: str, conf: BootConfIntervals
@@ -955,13 +1032,11 @@ class EvaluateMixin:
         returns: NDArray[np.float_],
         sample_size: int,
         samples: int,
-    ) -> pd.DataFrame:
-        dd_conf, dd_pct_conf = drawdown_conf(
-            changes, returns, sample_size, samples
-        )
+    ) -> _DrawdownResult:
+        metrics = drawdown_conf(changes, returns, sample_size, samples)
         df = pd.DataFrame(
-            zip(("99.9%", "99%", "95%", "90%"), dd_conf, dd_pct_conf),
+            zip(("99.9%", "99%", "95%", "90%"), *metrics),
             columns=("conf", "amount", "percent"),
         )
         df.set_index("conf", inplace=True)
-        return df
+        return _DrawdownResult(df=df, metrics=metrics)
