@@ -60,6 +60,7 @@ class Stop(NamedTuple):
         Union[
             int,
             float,
+            np.floating,
             Decimal,
             PriceType,
             Callable[[str, BarData], Union[int, float, Decimal]],
@@ -296,12 +297,10 @@ class Portfolio:
             sorted in ascending chronological order.
         position_bars: ``deque`` of snapshots of :class:`.Position` states on
             every bar, sorted in ascending chronological order.
+        win_rate: Running win rate of trades.
+        loss_rate: Running loss rate of trades.
     """
 
-    _order_id: int = 0
-    _entry_id: int = 0
-    _trade_id: int = 0
-
     def __init__(
         self,
         cash: float,
@@ -332,8 +331,14 @@ class Portfolio:
         self.symbols: set[str] = set()
         self.bars: deque[PortfolioBar] = deque()
         self.position_bars: deque[PositionBar] = deque()
+        self.win_rate: Decimal = Decimal()
+        self.loss_rate: Decimal = Decimal()
+        self._wins: Decimal = Decimal()
         self._logger = StaticScope.instance().logger
         self._stop_data: dict[int, _StopData] = {}
+        self._order_id: int = 0
+        self._entry_id: int = 0
+        self._trade_id: int = 0
 
     def _calculate_fees(self, fill_price: Decimal, shares: Decimal) -> Decimal:
         fees = Decimal()
@@ -442,6 +447,10 @@ class Portfolio:
             stop=None if stop_type is None else stop_type.value,
         )
         self.trades.append(trade)
+        if pnl > 0:
+            self._wins += 1
+        self.win_rate = self._wins / len(self.trades)
+        self.loss_rate = 1 - self.win_rate
 
     def _get_stop_amount(self, stop: Stop, price: Decimal) -> Decimal:
         if stop.percent is not None:
