@@ -23,7 +23,6 @@ from .common import (
     BarData,
     DataCol,
     Day,
-    ExecSymbol,
     IndicatorSymbol,
     ModelSymbol,
     PriceType,
@@ -73,33 +72,6 @@ from typing import (
 )
 
 
-def _decorate_execution_fn(fn: Callable[[ExecContext], None]) -> Callable:
-    def decorated_execution_fn(
-        ctx: ExecContext, session: dict, symbol: str, date: np.datetime64
-    ):
-        set_exec_ctx_data(ctx, session, symbol, date)
-        fn(ctx)
-        if ctx.buy_shares is not None and ctx.sell_shares is not None:
-            raise ValueError(
-                "For each symbol, only one of buy_shares or sell_shares can be"
-                " set per bar."
-            )
-        if ctx.buy_limit_price is not None and ctx.buy_shares is None:
-            raise ValueError(
-                "buy_shares must be set when buy_limit_price is set."
-            )
-        if ctx.sell_limit_price is not None and ctx.sell_shares is None:
-            raise ValueError(
-                "sell_shares must be set when sell_limit_price is set."
-            )
-        if not ctx.buy_shares and not ctx.sell_shares:
-            return
-        result = ctx.to_result()
-        return result
-
-    return decorated_execution_fn
-
-
 def _between(
     df: pd.DataFrame, start_date: datetime, end_date: datetime
 ) -> pd.DataFrame:
@@ -142,7 +114,9 @@ class BacktestMixin:
     def backtest_executions(
         self,
         executions: set[Execution],
-        sessions: Mapping[ExecSymbol, Mapping],
+        before_exec_fn: Optional[Callable[[Mapping[str, ExecContext]], None]],
+        after_exec_fn: Optional[Callable[[Mapping[str, ExecContext]], None]],
+        sessions: Mapping[str, Mapping],
         models: Mapping[ModelSymbol, TrainedModel],
         indicator_data: Mapping[IndicatorSymbol, pd.Series],
         test_data: pd.DataFrame,
@@ -166,9 +140,9 @@ class BacktestMixin:
 
         Args:
             executions: :class:`.Execution`\ s to run.
-            sessions: :class:`Mapping` of :class:`pybroker.common.ExecSymbol`
-                pairs to :class:`Mapping` of custom data that persists for
-                every bar during the :class:`.Execution`.
+            sessions: :class:`Mapping` of symbols to :class:`Mapping` of custom
+                data that persists for every bar during the
+                :class:`.Execution`.
             models: :class:`Mapping` of :class:`pybroker.common.ModelSymbol`
                 pairs to :class:`pybroker.common.TrainedModel`\ s.
             indicator_data: :class:`Mapping` of
@@ -199,26 +173,12 @@ class BacktestMixin:
         """
         test_dates = test_data[DataCol.DATE.value].unique()
         test_dates.sort()
-        exec_symbols = tuple(
-            ExecSymbol(exec.id, sym)
-            for sym in test_data[DataCol.SYMBOL.value].unique()
-            for exec in executions
-            if exec.fn is not None and sym in exec.symbols
-        )
+        test_syms = test_data[DataCol.SYMBOL.value].unique()
         test_data = (
             test_data.reset_index(drop=True)
             .set_index([DataCol.SYMBOL.value, DataCol.DATE.value])
             .sort_index()
         )
-        test_symbols = frozenset(
-            exec_symbol.symbol for exec_symbol in exec_symbols
-        )
-        sym_exec_dates = {
-            sym: frozenset(test_data.loc[pd.IndexSlice[sym, :]].index.values)
-            for sym in test_symbols
-        }
-        buy_sched: dict[np.datetime64, list[ExecResult]] = defaultdict(list)
-        sell_sched: dict[np.datetime64, list[ExecResult]] = defaultdict(list)
         sym_end_index: dict[str, int] = defaultdict(int)
         col_scope = ColumnScope(test_data)
         price_scope = PriceScope(col_scope, sym_end_index)
@@ -226,21 +186,32 @@ class BacktestMixin:
         input_scope = ModelInputScope(col_scope, ind_scope)
         pred_scope = PredictionScope(models, input_scope)
         pending_order_scope = PendingOrderScope()
-        exec_ctx = ExecContext(
-            portfolio=portfolio,
-            col_scope=col_scope,
-            ind_scope=ind_scope,
-            input_scope=input_scope,
-            pred_scope=pred_scope,
-            pending_order_scope=pending_order_scope,
-            models=models,
-            sym_end_index=sym_end_index,
-        )
-        exec_fns = {
-            exec.id: _decorate_execution_fn(exec.fn)
-            for exec in executions
-            if exec.fn is not None
+        exec_ctxs: dict[str, ExecContext] = {}
+        exec_fns: dict[str, Callable[[ExecContext], None]] = {}
+        for sym in test_syms:
+            for exec in executions:
+                if sym not in exec.symbols:
+                    continue
+                exec_ctxs[sym] = ExecContext(
+                    symbol=sym,
+                    portfolio=portfolio,
+                    col_scope=col_scope,
+                    ind_scope=ind_scope,
+                    input_scope=input_scope,
+                    pred_scope=pred_scope,
+                    pending_order_scope=pending_order_scope,
+                    models=models,
+                    sym_end_index=sym_end_index,
+                    session=sessions[sym],
+                )
+                if exec.fn is not None:
+                    exec_fns[sym] = exec.fn
+        sym_exec_dates = {
+            sym: frozenset(test_data.loc[pd.IndexSlice[sym, :]].index.values)
+            for sym in exec_ctxs.keys()
         }
+        buy_sched: dict[np.datetime64, list[ExecResult]] = defaultdict(list)
+        sell_sched: dict[np.datetime64, list[ExecResult]] = defaultdict(list)
         if pos_size_handler is not None:
             pos_ctx = PosSizeContext(
                 portfolio=portfolio,
@@ -250,6 +221,7 @@ class BacktestMixin:
                 pred_scope=pred_scope,
                 pending_order_scope=pending_order_scope,
                 models=models,
+                sessions=sessions,
                 sym_end_index=sym_end_index,
                 max_long_positions=max_long_positions,
                 max_short_positions=max_short_positions,
@@ -259,11 +231,21 @@ class BacktestMixin:
         buy_results: deque[ExecResult] = deque()
         sell_results: deque[ExecResult] = deque()
         exit_syms: deque[str] = deque()
+        active_ctxs: dict[str, ExecContext] = {}
         for i, date in enumerate(test_dates):
-            for sym in test_symbols:
+            active_ctxs.clear()
+            for sym, ctx in exec_ctxs.items():
                 if date not in sym_exec_dates[sym]:
                     continue
+                active_ctxs[sym] = ctx
                 sym_end_index[sym] += 1
+                set_exec_ctx_data(ctx, date)
+                if (
+                    exit_dates
+                    and sym in exit_dates
+                    and date == exit_dates[sym]
+                ):
+                    exit_syms.append(sym)
             is_buy_sched = date in buy_sched
             is_sell_sched = date in sell_sched
             if is_buy_sched and (
@@ -303,14 +285,15 @@ class BacktestMixin:
                 )
             portfolio.check_stops(date, price_scope)
             portfolio.capture_bar(date, test_data)
-            for exec_symbol in exec_symbols:
-                if date not in sym_exec_dates[exec_symbol.symbol]:
-                    continue
-                if exit_dates and date == exit_dates[exec_symbol.symbol]:
-                    exit_syms.append(exec_symbol.symbol)
-                result = exec_fns[exec_symbol.exec_id](
-                    exec_ctx, sessions[exec_symbol], exec_symbol.symbol, date
-                )
+            if before_exec_fn is not None:
+                before_exec_fn(active_ctxs)
+            for sym, ctx in active_ctxs.items():
+                if sym in exec_fns:
+                    exec_fns[sym](ctx)
+            if after_exec_fn is not None:
+                after_exec_fn(active_ctxs)
+            for ctx in active_ctxs.values():
+                result = self._to_result(ctx)
                 if result is None:
                     continue
                 if result.buy_shares is not None:
@@ -350,6 +333,24 @@ class BacktestMixin:
             if i % 10 == 0 or i == len(test_dates) - 1:
                 logger.backtest_executions_loading(i + 1)
 
+    def _to_result(self, ctx: ExecContext) -> Optional[ExecResult]:
+        if ctx.buy_shares is not None and ctx.sell_shares is not None:
+            raise ValueError(
+                "For each symbol, only one of buy_shares or sell_shares can be"
+                " set per bar."
+            )
+        if ctx.buy_limit_price is not None and ctx.buy_shares is None:
+            raise ValueError(
+                "buy_shares must be set when buy_limit_price is set."
+            )
+        if ctx.sell_limit_price is not None and ctx.sell_shares is None:
+            raise ValueError(
+                "sell_shares must be set when sell_limit_price is set."
+            )
+        if not ctx.buy_shares and not ctx.sell_shares:
+            return None
+        return ctx.to_result()
+
     def _exit_position(
         self,
         portfolio: Portfolio,
@@ -795,6 +796,12 @@ class Strategy(
         else:
             self._config = StrategyConfig()
         self._executions: set[Execution] = set()
+        self._before_exec_fn: Optional[
+            Callable[[Mapping[str, ExecContext]], None]
+        ] = None
+        self._after_exec_fn: Optional[
+            Callable[[Mapping[str, ExecContext]], None]
+        ] = None
         self._pos_size_handler: Optional[
             Callable[[PosSizeContext], None]
         ] = None
@@ -922,6 +929,30 @@ class Strategy(
             )
         )
 
+    def set_before_exec(
+        self, fn: Optional[Callable[[Mapping[str, ExecContext]], None]]
+    ):
+        r""":class:`Callable[[Mapping[str, ExecContext]]` that runs before all
+        execution functions.
+
+        Args:
+            fn: :class:`Callable` that takes a :class:`Mapping` of all ticker
+                symbols to :class:`ExecContext`\ s.
+        """
+        self._before_exec_fn = fn
+
+    def set_after_exec(
+        self, fn: Optional[Callable[[Mapping[str, ExecContext]], None]]
+    ):
+        r""":class:`Callable[[Mapping[str, ExecContext]]` that runs after all
+        execution functions.
+
+        Args:
+            fn: :class:`Callable` that takes a :class:`Mapping` of all ticker
+                symbols to :class:`ExecContext`\ s.
+        """
+        self._after_exec_fn = fn
+
     def clear_executions(self):
         """Clears executions that were added with :meth:`.add_execution`."""
         self._executions.clear()
@@ -1135,7 +1166,11 @@ class Strategy(
                 ),
                 disable_parallel=disable_parallel,
             )
-            train_only = all(map(lambda e: e.fn is None, self._executions))
+            train_only = (
+                self._before_exec_fn is None
+                and self._after_exec_fn is None
+                and all(map(lambda e: e.fn is None, self._executions))
+            )
             portfolio = Portfolio(
                 self._config.initial_cash,
                 self._config.fee_mode,
@@ -1200,14 +1235,11 @@ class Strategy(
         shuffle: bool,
         train_only: bool,
     ):
-        sessions: dict[ExecSymbol, dict] = {}
+        sessions: dict[str, dict] = defaultdict(dict)
         exit_dates: dict[str, np.datetime64] = {}
-        for exec in self._executions:
-            if exec.fn is None:
-                continue
-            for sym in exec.symbols:
-                sessions[ExecSymbol(exec.id, sym)] = {}
-                if self._config.exit_on_last_bar:
+        if self._config.exit_on_last_bar:
+            for exec in self._executions:
+                for sym in exec.symbols:
                     sym_dates = df[df[DataCol.SYMBOL.value] == sym][
                         DataCol.DATE.value
                     ].values
@@ -1250,6 +1282,8 @@ class Strategy(
             if not train_only and not test_data.empty:
                 self.backtest_executions(
                     executions=self._executions,
+                    before_exec_fn=self._before_exec_fn,
+                    after_exec_fn=self._after_exec_fn,
                     sessions=sessions,
                     models=models,
                     indicator_data=indicator_data,
@@ -1395,6 +1429,7 @@ class Strategy(
             calc_bootstrap=calc_bootstrap,
             bootstrap_sample_size=self._config.bootstrap_sample_size,
             bootstrap_samples=self._config.bootstrap_samples,
+            sharpe_length=self._config.sharpe_length,
         )
         metrics_df = pd.DataFrame(
             dataclasses.asdict(eval_result.metrics).items(),
