@@ -1913,6 +1913,32 @@ class TestStrategy:
         assert np.isnan(sell_order["limit_price"])
         assert sell_order["fees"] == 0
 
+    def test_backtest_when_cancel_stop(self, data_source_df):
+        def exec_fn(ctx):
+            if ctx.bars == 1:
+                ctx.buy_shares = 100
+                ctx.stop_loss = 10
+            elif ctx.bars == 10:
+                entry = tuple(ctx.long_pos().entries)[0]
+                stop = next(iter(entry.stops))
+                assert ctx.cancel_stop(stop_id=stop.id)
+
+        df = data_source_df[data_source_df["symbol"] == "SPY"]
+        dates = df["date"].unique()
+        dates = dates[dates <= np.datetime64(END_DATE)]
+        strategy = Strategy(data_source_df, START_DATE, END_DATE)
+        strategy.add_execution(exec_fn, "SPY")
+        result = strategy.backtest(calc_bootstrap=False)
+        assert not len(result.trades)
+        assert len(result.orders) == 1
+        buy_order = result.orders.iloc[0]
+        assert buy_order["type"] == "buy"
+        assert buy_order["symbol"] == "SPY"
+        assert buy_order["date"] == dates[1]
+        assert buy_order["shares"] == 100
+        assert np.isnan(buy_order["limit_price"])
+        assert buy_order["fees"] == 0
+
     def test_backtest_when_cancel_stops(self, data_source_df):
         def exec_fn(ctx):
             if ctx.bars == 1:
